@@ -10,10 +10,10 @@ class DatasetProcessor:
     def __init__(
         self,
         cache_path: str = "petharbor_cache/",
-    ):  
+    ):
         self.cache_path = cache_path
         self.logger = logging.getLogger(__name__)
-        self._last_input_format = None # Initialize
+        self._last_input_format = None  # Initialize
 
     def validate_dataset(self, dataset, text_column) -> None:
         if text_column not in dataset.column_names:
@@ -27,7 +27,6 @@ class DatasetProcessor:
         )
         return clean_dataset
 
-
     def load_dataset_file(self, file_path: str, split: str = "train") -> Dataset:
         """
         Loads a dataset from a file or directory, attempting to use HuggingFace's
@@ -64,7 +63,7 @@ class DatasetProcessor:
                     f"Failed to load '{dataset_format}' dataset from {file_path}: {e}"
                 )
                 raise
-        elif file_extension == '.pkl':
+        elif file_extension == ".pkl":
             try:
                 loaded_dataset = pd.read_pickle(file_path)
                 loaded_dataset = Dataset.from_pandas(loaded_dataset)
@@ -85,9 +84,7 @@ class DatasetProcessor:
                 )
                 raise
         if not loaded_dataset:
-            error_message = (
-                f"Dataset not found or could not be loaded from {file_path}"
-            )
+            error_message = f"Dataset not found or could not be loaded from {file_path}"
             self.logger.error(error_message)
             raise ValueError(error_message)
         if split in loaded_dataset:
@@ -103,7 +100,8 @@ class DatasetProcessor:
             default_split = list(loaded_dataset.keys())[0]
             if split != default_split:
                 self.logger.info(
-                    f"Returning the only available split: '{default_split}'.")
+                    f"Returning the only available split: '{default_split}'."
+                )
             return loaded_dataset[default_split]
         else:
             error_message = (
@@ -113,8 +111,6 @@ class DatasetProcessor:
             self.logger.error(error_message)
             raise ValueError(error_message)
 
-
-
     def load_cache(self, dataset, cache=False) -> tuple:
         """
         Filter out anonymised data from the dataset using a cache.
@@ -146,8 +142,10 @@ class DatasetProcessor:
                     if cache not in dataset.column_names:
                         self.logger.error(f"Column '{cache}' not found in dataset.")
                         raise ValueError(f"Column '{cache}' not found in dataset.")
-                    
-                    self.full_cache_path = os.path.join(self.cache_path, f"{cache}_cache.txt")
+
+                    self.full_cache_path = os.path.join(
+                        self.cache_path, f"{cache}_cache.txt"
+                    )
                     if os.path.exists(self.full_cache_path):
                         with open(self.full_cache_path, "r") as f:
                             cached_ids = set(line.strip() for line in f)
@@ -162,7 +160,9 @@ class DatasetProcessor:
                         # Create the cache file if it doesn't exist
                         # create the directory if it doesn't exist
                         os.makedirs(os.path.dirname(self.cache_path), exist_ok=True)
-                        self.cache_path = os.path.join(self.cache_path, f"{cache}_cache.txt")
+                        self.cache_path = os.path.join(
+                            self.cache_path, f"{cache}_cache.txt"
+                        )
                         with open(self.full_cache_path, "w") as f:
                             f.write("")
 
@@ -196,11 +196,17 @@ class DatasetProcessor:
                 self.logger.info(
                     f"Processing {len(target_dataset)} non-anonymised rows"
                 )
-                return target_dataset, completed_dataset, 
+                return (
+                    target_dataset,
+                    completed_dataset,
+                )
         else:
             self.logger.info("Cache disabled | Processing all data")
-            return target_dataset, completed_dataset, 
-        
+            return (
+                target_dataset,
+                completed_dataset,
+            )
+
     def save_dataset_file(
         self,
         target_dataset: Dataset,
@@ -236,24 +242,30 @@ class DatasetProcessor:
                 with open(self.full_cache_path, "a") as f:
                     for id in cache_ids:
                         f.write(f"{id}\n")
-            if completed_dataset is not None:            
+            if completed_dataset is not None:
                 original_df = completed_dataset.to_pandas()
                 target_df = pd.concat([original_df, target_df], ignore_index=True)
 
         if save_path is None:
             base_name = f"{date}_anonymised"
             # changed this
-            save_format = self._last_input_format if hasattr(self, "_last_input_format") and self._last_input_format in [
-                ".csv",
-                ".arrow",
-                ".json",
-                ".parquet",
-                ".pkl",
-            ] else ".csv"
+            save_format = (
+                self._last_input_format
+                if hasattr(self, "_last_input_format")
+                and self._last_input_format
+                in [
+                    ".csv",
+                    ".arrow",
+                    ".json",
+                    ".parquet",
+                    ".pkl",
+                ]
+                else ".csv"
+            )
             save_path = os.path.join(f"{base_name}{save_format}")
-          
+
         if "." in save_path:
-             save_format = os.path.splitext(save_path)[1].lower()
+            save_format = os.path.splitext(save_path)[1].lower()
 
         try:
             if save_format == ".csv":
@@ -278,4 +290,4 @@ class DatasetProcessor:
                 )
         except Exception as e:
             self.logger.error(f"Failed to save dataset to {save_path}: {e}")
-            raise 
\ No newline at end of file
+            raise
